import assert from 'assert';
import sinon from 'sinon';
import * as request from '../../../../request';

import generalFixture from '../../../generalFixture';
import urls from '../../../../urls';

import * as answerSearch from './index.js';
import {HttpData} from './fixtures';


test('API QuestionAnswering Answer search should call request with correct arguments', function() {
  const requestStub = sinon.stub(request, 'request');
  const parent = {
    search: answerSearch.default,
    options: {
      host: 'test'
    }
  }

  const spy = sinon.spy();

  Object.defineProperty(parent.options, 'authTokenProvider', {
    get: spy
  });

  parent.search(generalFixture.modelgroupId,
                generalFixture.channel,
                generalFixture.standardized_language,
                generalFixture.query,
                generalFixture.active,
                generalFixture.paginationParams.page,
                generalFixture.paginationParams.per_page);

  const stubArgs = requestStub.getCall(0).args;
  const apiUrl = urls.questionAnswering.answer.search(generalFixture.modelgroupId,
                                                      generalFixture.paginationParams.page,
                                                      generalFixture.paginationParams.per_page,
                                                      generalFixture.active,
                                                      generalFixture.standardized_language,
                                                      generalFixture.channel,
                                                      generalFixture.query);
  const expectedUrl = parent.options.host + apiUrl;
  assert.equal(stubArgs[0], expectedUrl);
  assert.deepEqual(stubArgs[1], HttpData.results.search.options);
  assert(spy.called);
  requestStub.restore();
});