import assert from 'assert';
import sinon from 'sinon';
import * as request from '../../../../request';

import generalFixture from '../../../generalFixture';
import urls from '../../../../urls';

import * as logCreate from './index.js';
import {HttpData, EmptyMessagesEmptyMetadata} from './fixtures';

test('requestParamsBuilder build correct object empty messages list, empty metadata list', function() {
  const actualParams = logCreate.requestParamsBuilder(EmptyMessagesEmptyMetadata.externalId,
                                                      EmptyMessagesEmptyMetadata.createdAt,
                                                      EmptyMessagesEmptyMetadata.messages,
                                                      EmptyMessagesEmptyMetadata.metadata);

  // Update fixtures to be imported from global fixture file. 
  assert.deepEqual(actualParams, { externalId: EmptyMessagesEmptyMetadata.externalId,
                                   createdAt: EmptyMessagesEmptyMetadata.createdAt,
                                   messages: EmptyMessagesEmptyMetadata.messages,
                                   metadata: EmptyMessagesEmptyMetadata.metadata });
});


test('API QuestionAnswering Log create should call request with correct arguments', function() {
  const requestStub = sinon.stub(request, 'request');
  const parent = {
    create: logCreate.default,
    options: {
      host: 'test'
    }
  }

  const spy = sinon.spy();

  Object.defineProperty(parent.options, 'authTokenProvider', {
    get: spy
  });

  parent.create(generalFixture.modelgroupId,
                EmptyMessagesEmptyMetadata.externalId,
                EmptyMessagesEmptyMetadata.createdAt,
                EmptyMessagesEmptyMetadata.messages,
                EmptyMessagesEmptyMetadata.metadata);

  const stubArgs = requestStub.getCall(0).args;
  const apiUrl = urls.questionAnswering.log.create(generalFixture.modelgroupId);
  const expectedUrl = parent.options.host + apiUrl;
  assert.equal(stubArgs[0], expectedUrl);
  assert.deepEqual(stubArgs[1], HttpData.results.create.options);
  assert(spy.called);

  requestStub.restore();
});
