import assert from 'assert';
import sinon from 'sinon';

import * as request from '../../../../request';
import deleteAPI from '.';
import fixtures from './fixtures';
import generalFixture from '../../../generalFixture';
import urls from '../../../../urls';

test('API QuestionAnswering ModelGroup DeleteAddOnSchema should call request with correct arguments', function() {
  const requestStub = sinon.stub(request, 'request');
  const parent = {
    delete: deleteAPI,
    options: {
      host: 'test'
    }
  }

  const spy = sinon.spy();

  Object.defineProperty(parent.options, 'authTokenProvider', {
    get: spy
  });

  parent.delete(generalFixture.modelgroupId, fixtures.standardizedLanguage, fixtures.channel);

  const stubArgs = requestStub.getCall(0).args;

  const apiUrl = urls.questionAnswering.modelGroup.deleteAddOnSchema(generalFixture.modelgroupId);
  const expectedUrl = parent.options.host + apiUrl;
  assert.equal(stubArgs[0], expectedUrl);
  assert.deepEqual(stubArgs[1], fixtures.results.deleteAddOnSchema.options);
  assert(spy.called);

  requestStub.restore();
});
