import assert from 'assert';
import sinon from 'sinon';

import * as request from '../../../../request';
import createAPI from '.';
import fixtures from './fixtures';
import generalFixture from '../../../generalFixture';
import urls from '../../../../urls';

test('API QuestionAnswering ModelVersion CreateHistoricalResponses should call request with correct arguments',
  function() {
    const requestStub = sinon.stub(request, 'request');
    const parent = {
      create: createAPI,
      options: {
        host: 'test'
      }
    }

    const spy = sinon.spy();

    Object.defineProperty(parent.options, 'authTokenProvider', {
      get: spy
    });

    parent.create(
      generalFixture.modelgroupId,
      fixtures.standardizedLanguages,
      fixtures.channels,
      fixtures.startTraining,
      fixtures.aiType
    );

    const stubArgs = requestStub.getCall(0).args;

    const apiUrl = urls.questionAnswering.modelVersion.createHistoricalResponses(generalFixture.modelgroupId);
    const expectedUrl = parent.options.host + apiUrl;
    assert.equal(stubArgs[0], expectedUrl);
    assert.deepEqual(stubArgs[1], fixtures.results.createHistoricalResponses.options);
    assert(spy.called);

    requestStub.restore();
  }
);
