import assert from 'assert';
import sinon from 'sinon';

import * as request from '../../../../request';
import statusAPI from '.';
import fixtures from './fixtures';
import generalFixture from '../../../generalFixture';
import urls from '../../../../urls';
import { buildQueryParams } from '../../../../utils';

test('API QuestionAnswering ModelVersion StatusHistoricalResponses should call request with correct arguments',
  function() {
    const requestStub = sinon.stub(request, 'request');
    const parent = {
      status: statusAPI,
      options: {
        host: 'test'
      }
    }

    const spy = sinon.spy();

    Object.defineProperty(parent.options, 'authTokenProvider', {
      get: spy
    });

    parent.status(generalFixture.modelgroupId, generalFixture.modelversionId, generalFixture.paginationParams);

    let stubArgs = requestStub.getCall(0).args;

    const apiUrl = urls.questionAnswering.modelVersion
      .statusHistoricalResponses(generalFixture.modelgroupId, generalFixture.modelversionId);
    let expectedUrl = parent.options.host + apiUrl + '?' + buildQueryParams(generalFixture.paginationParams);
    assert.equal(stubArgs[0], expectedUrl);
    assert.deepEqual(stubArgs[1], fixtures.results.statusHistoricalResponses.options);
    assert(spy.called);

    parent.status(generalFixture.modelgroupId, generalFixture.modelversionId);

    stubArgs = requestStub.getCall(1).args;

    expectedUrl = parent.options.host + apiUrl;
    assert.equal(stubArgs[0], expectedUrl);
    assert.deepEqual(stubArgs[1], fixtures.results.statusHistoricalResponses.options);
    assert(spy.calledTwice);

    requestStub.restore();
  }
);
