import assert from 'assert';
import sinon from 'sinon';

import fixtures from './fixtures';
import { request } from '.';

beforeAll(() => {
  global.fetch = () => {};
});

test('Request should make a request', function() {
  const fetchStub = sinon.stub(global, 'fetch');

  request(fixtures.inputs.normalRequest.url, { ...fixtures.inputs.normalRequest.options });
  const stubArgs = fetchStub.getCall(0).args;

  assert.equal(stubArgs[0], fixtures.results.normalRequest.url);
  assert.deepEqual(stubArgs[1], fixtures.results.normalRequest.options);

  fetchStub.restore();
});

test('Request should add Authorization header to options', function() {
  const fetchStub = sinon.stub(global, 'fetch');

  let authToken = fixtures.authToken;
  request(fixtures.inputs.normalRequest.url, { ...fixtures.inputs.normalRequest.options }, authToken);
  let stubArgs = fetchStub.getCall(0).args;

  assert.equal(stubArgs[0], fixtures.results.withAuth.url);
  assert.deepEqual(stubArgs[1], fixtures.results.withAuth.options);

  authToken = () => {
    return fixtures.authToken;
  };
  request(fixtures.inputs.normalRequest.url, fixtures.inputs.normalRequest.options, authToken);
  stubArgs = fetchStub.getCall(1).args;

  assert.equal(stubArgs[0], fixtures.results.withAuth.url);
  assert.deepEqual(stubArgs[1], fixtures.results.withAuth.options);

  fetchStub.restore();
});
